@@ -54,10 +54,6 @@ class OnionprobeTor:
         import socket
         control_address = socket.gethostbyname(control_address)
 
-        # Workaround for https://github.com/torproject/stem/issues/112
-        if self.get_config('log_level') != 'debug':
-            stem.util.log.get_logger().propagate = False
-
         if self.get_config('launch_tor'):
             if self.launch_tor() is False:
                 self.log("Error initializing Tor", "critical")
@@ -207,7 +203,7 @@ class OnionprobeTor:
                 self.log(term.format(line), 'error')
 
         try:
-            self.log('Initializing Tor process...')
+            self.log('Initializing Tor process (might take a while to bootstrap)...')
 
             tor_address         = self.get_config('tor_address')
             control_password    = self.get_config('control_password', self.gen_control_password())
